@@ -52,7 +52,8 @@ struct ether *_getethent(void)
 
     
     if (efp == NULL)
-	setethent();
+	_setethent();
+    
     if (efp == NULL)
 	return NULL;
 
@@ -70,12 +71,12 @@ struct ether *_getethbyname(char *name)
     struct ether *ep;
     
 
-    setethent();
+    _setethent();
 
-    while ((ep = getethent()) && strcmp(name, ep->name) != 0)
+    while ((ep = _getethent()) && strcmp(name, ep->name) != 0)
 	;
 
-    endethent();
+    _endethent();
 
     return ep;
 }
@@ -85,13 +86,13 @@ struct ether *_getethbyaddr(struct ether_addr *addr)
     struct ether *ep;
     
 
-    setethent();
+    _setethent();
 
-    while ((ep = getethent()) &&
+    while ((ep = _getethent()) &&
 	   memcmp(addr, &ep->addr, sizeof(struct ether_addr)) != 0)
 	;
 
-    endethent();
+    _endethent();
 
     return ep;
 }
