@@ -48,11 +48,11 @@ static struct
     { "passwd",		"passwd.byname" },
     { "group",		"group.byname" },
     { "networks",	"networks.byaddr" },
-    { "hosts",		"hosts.byaddr" },
+    { "hosts",		"hosts.byname" },
     { "protocols",	"protocols.bynumber" },
     { "services",	"services.byname" },
     { "aliases",	"mail.aliases" },
-    { "ethers",		"ethers.byaddr" },
+    { "ethers",		"ethers.byname" },
 	  
     { "rpc",		"rpc.bynumber" },
     { "netmasks",	"netmasks.byaddr" },
